import javax.swing.*;
import java.util.Scanner;
import java.io.PrintWriter;
import java.io.IOException;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.FlowLayout;
import java.io.BufferedReader;

/**
 * Main program ClientWindow.
 * 
 * @author Stephen Bloch
 * @version 10, 11 April 2007
 * 
 * In this version, there's a TextArea for messages received, and a TextField for sending.
 */
public class ClientWindow extends JFrame
{
        // instance variables
        private static final int ROWS = 20;
        private static final int COLUMNS = 30;

        /**
         * The main method, for command-line invocation.
         * 
         * @param  args   the command line arguments
         */
        public static void main (String[] args)
        {
            final String hostname = (args.length > 0) ? args[0] : "localhost";
            /*
            System.out.println ("There were " + args.length + " arguments:");
                for (int ii=0; ii<args.length; ++ii) {
                    System.out.println ("" + ii + ": " + args[ii]);
                }
                */
           javax.swing.SwingUtilities.invokeLater (new Runnable() {
               public void run () {
                    JFrame.setDefaultLookAndFeelDecorated(true);
    
                    // Create the window and set its size.
                    new ClientWindow (hostname);
                }
            });
        } // end of main method
        
        public ClientWindow (String hostname) {
            super("Client version 10");
            this.setSize (500, 500);
            this.setDefaultCloseOperation (JFrame.EXIT_ON_CLOSE);
            
            final Connection host = new ConnectionToHost (hostname);
            final PrintWriter out = host.getOut();
            BufferedReader in = host.getIn();
            
            this.setLayout (new FlowLayout());
            final JTextArea log = new JTextArea (ROWS, COLUMNS);
            final JTextField userInput = new JTextField (COLUMNS);
            this.add(log);
            this.add(userInput);
            this.setVisible (true);
            
            new Thread(new ClientEars(in, log)).start();
            
            userInput.addActionListener (new ActionListener () {
                public void actionPerformed (ActionEvent event) {
                    if (userInput.getText().equals("quit")) {
                        try {
                            host.close ();
                            System.exit (1);
                        }
                        catch (IOException exception) {
                            System.err.println ("Client failed to close connection: " + exception);
                        }
                    }
                    else {
                        System.err.println ("Sending message \"" + userInput.getText() + "\".");
                        out.println (userInput.getText());
                        out.flush ();
                    }
                }
            });
        }
}
