import java.io.PrintWriter;
import java.io.BufferedReader;
import java.io.IOException;
import java.net.ServerSocket;
/**
 * Main program TextBasedServer.
 * 
 * @author Stephen Bloch
 * @version 11, 11 April 2007
 * In this version, I've converted some of the static variables to instance
 * variables, including an array of currently-active Connections.
 * I've also moved the ServerSideThread class to an inner class of TextBasedServer,
 * so it can call private methods to maintain said array.
 */
public class TextBasedServer
{
    private static final int MAX_CLIENTS = 3;
    private int clientNumber = 0;
    private Connection[] clients = new Connection[MAX_CLIENTS];
    private ServerSocket ss;
    
    
        /**
         * The main method, for command-line invocation.
         * 
         * @param  args   the command line arguments
         */
        public static void main (String[] args)
        {
            TextBasedServer theServer = new TextBasedServer();
        }
        
        private TextBasedServer () {            
            try {
                this.ss = new ServerSocket (Constants.PORT_NUM);
                
                for (int ii=0; ii<MAX_CLIENTS; ++ii)
                {
                    new Thread(new ServerSideThread(ii, ss)).start();
                }
            }
            catch (IOException e)
            {
                System.err.println ("Server got IOException while creating ServerSocket: " + e);
            }
            
        }
        
        private synchronized int getNextClientNumber () {
            return ++(this.clientNumber);
        }
        
        private synchronized void addClient (int threadNumber, Connection client) {
            this.clients[threadNumber] = client;
            System.err.println ("Set clients[" + threadNumber + "]");
        }
        
        private synchronized void removeClient (int threadNumber) {
            this.clients[threadNumber] = null;
            System.err.println ("Cleared clients[" + threadNumber + "]");
        }
        
    /**
     * A single thread of the server.
     * 
     * @author Stephen Bloch
     * @version 11, 11 April 2007
     * Main change: moved into an inner class of TextBasedServer
     */
    class ServerSideThread implements Runnable
    {
        // instance variables
        private int threadNumber;
        private ServerSocket ss;
        private int clientNumber;
        
        public ServerSideThread (int threadNumber, ServerSocket ss) {
            this.threadNumber = threadNumber;
            this.ss = ss;
        }
        
        public void run () {
            while (true) {
                Connection client = new ServerSideConnection (ss);
                TextBasedServer.this.addClient (this.threadNumber, client);
                this.clientNumber = TextBasedServer.this.getNextClientNumber();
                
                PrintWriter out = client.getOut();
                BufferedReader in = client.getIn();
                
                out.println ("Welcome, client " + this.clientNumber);
                
                while (true) { // really until end of file
                    String message;
                    try {
                        message = in.readLine();
                    }
                    catch (IOException e) {
                        System.err.println ("Server got IOException on read: " + e);
                        break;
                    }
                    if (message == null) // i.e. end of input
                    {
                        System.err.println ("Server reached end of input.");
                        break;
                    }
                    System.out.println ("Client " + this.clientNumber + " says \"" + message + "\"");
                } // reached end of file
                System.out.println ("Connection to client " + this.clientNumber + " closed.");
                TextBasedServer.this.removeClient (this.threadNumber);
            } // end while(true)
        }            
}

}
