import javax.swing.*;
import java.util.Scanner;
import java.io.PrintWriter;
import java.io.IOException;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.FlowLayout;

/**
 * Main program ClientWindow.
 * 
 * @author Stephen Bloch
 * @version 5, 11 April 2007
 * 
 * In this version, we attach to either "localhost" or a host specified on the command line.
 * I've tested this using no command-line arg (i.e. "localhost"), and on a Mac with the IP address
 * of that same Mac, and on Windows with the IP address of that same Windows machine, and with the
 * server on my Mac and the client on my Windows box, and with the server on my Windows box and
 * the client on my Mac.
 */
public class ClientWindow extends JFrame
{
        // instance variables
        private static final int COLUMNS = 30;

        /**
         * The main method, for command-line invocation.
         * 
         * @param  args   the command line arguments
         */
        public static void main (String[] args)
        {
            final String hostname = (args.length > 0) ? args[0] : "localhost";
            /*
            System.out.println ("There were " + args.length + " arguments:");
                for (int ii=0; ii<args.length; ++ii) {
                    System.out.println ("" + ii + ": " + args[ii]);
                }
                */
           javax.swing.SwingUtilities.invokeLater (new Runnable() {
               public void run () {
                    JFrame.setDefaultLookAndFeelDecorated(true);
    
                    // Create the window and set its size.
                    new ClientWindow (hostname);
                }
            });
        } // end of main method
        
        public ClientWindow (String hostname) {
            super("Client version 6");
            this.setSize (500, 100);
            this.setDefaultCloseOperation (JFrame.EXIT_ON_CLOSE);
            
            final Connection host = new ConnectionToHost (hostname);
            final PrintWriter out = host.getOut();
            // BufferedReader in = host.getIn();
            
            this.setLayout (new FlowLayout());
            final JTextField userInput = new JTextField (COLUMNS);
            JButton send = new JButton ("Send");
            this.add(userInput);
            this.add(send);
            this.setVisible (true);
            
            send.addActionListener (new ActionListener () {
                public void actionPerformed (ActionEvent event) {
                    if (userInput.getText().equals("quit")) {
                        try {
                            host.close ();
                            System.exit (1);
                        }
                        catch (IOException exception) {
                            System.err.println ("Client failed to close connection: " + exception);
                        }
                    }
                    else {
                        System.err.println ("Sending message \"" + userInput.getText() + "\".");
                        out.println (userInput.getText());
                        out.flush ();
                    }
                }
            });
        }
}
