import java.net.ServerSocket;
import java.io.PrintWriter;
import java.io.BufferedReader;
import java.io.IOException;
/**
 * A single thread of the server.
 * 
 * @author Stephen Bloch
 * @version 8, 11 April 2007
 * In the current version, when the connection is closed, the thread stays
 * around to handle another client.
 */
public class ServerSideThread implements Runnable
{
        // instance variables
        private ServerSocket ss;
        
        public ServerSideThread (ServerSocket ss) {
            this.ss = ss;
        }
        
        public void run () {
            while (true) {
                Connection client = new ServerSideConnection (ss);
                
                PrintWriter out = client.getOut();
                BufferedReader in = client.getIn();
                
                while (true) { // really until end of file
                    String message;
                    try {
                        message = in.readLine();
                    }
                    catch (IOException e) {
                        System.err.println ("Server got IOException on read: " + e);
                        break;
                    }
                    if (message == null) // i.e. end of input
                    {
                        System.err.println ("Server reached end of input.");
                        break;
                    }
                    System.out.println ("Client says \"" + message + "\"\n");
                }
                System.out.println ("Connection closed.");
            } // end while(true)
        }            
}
