import javax.swing.*;
import java.net.ServerSocket;
import java.net.Socket;
import java.io.*;

/**
 * Main program ServerWindow.
 * 
 * @author Stephen Bloch
 * @version 6, 11 April 2007
 * 
 * In this version, we use BufferedReader rather than Scanner so we can
 * perhaps get it running on panther (which doesn't have Java 1.5 installed yet).
 */
public class ServerWindow extends JFrame
{
        // instance variables - replace the example below with your own
        private final static int ROWS = 40;
        private final static int COLUMNS = 60;
        private static JTextArea log = null;

        /**
         * The main method, for command-line invocation.
         * 
         * @param  args   the command line arguments
         */
        public static void main (String[] args)
        {
            /*
            System.out.println ("There were " + args.length + " arguments:");
            for (int ii=0; ii<args.length; ++ii) {
                System.out.println ("" + ii + ": " + args[ii]);
            }
            */
           javax.swing.SwingUtilities.invokeLater (new Runnable() {
               public void run () {
                    JFrame.setDefaultLookAndFeelDecorated(true);
    
                    // Create the window and set its size.
                    new ServerWindow ();
                }
            });

            Connection client = new ServerSideConnection ();
           
            while (log == null) {   // wait for the invokeLater to set up the window
                Thread.yield();
            }
            
            handleConnection (client, log);
            
        } // end of main method
        
        public ServerWindow () {
            this.setSize (300, 600);
            this.setDefaultCloseOperation (JFrame.EXIT_ON_CLOSE);
            
            log = new JTextArea (ROWS, COLUMNS);
            this.add(log);
            this.setVisible (true);
        }
        
        private static void handleConnection (Connection client, JTextArea log) {
            PrintWriter out = client.getOut();
            BufferedReader in = client.getIn();
            
            while (true) { // really until end of file
                String message;
                try {
                    message = in.readLine();
                }
                catch (IOException e) {
                    System.err.println ("Server got IOException on read: " + e);
                    break;
                }
                if (message == null) // i.e. end of input
                {
                    System.err.println ("Server reached end of input.");
                    break;
                }
                log.append ("Client says \"" + message + "\"\n");
                System.out.println ("Client says \"" + message + "\"\n");
            }
            log.append ("Connection closed.");
            System.exit (1);
            // although in the Real World we might sit around and wait for another connection
        }
}
